==> ocg_app-0.0.24.tar.gz: lib/src/helpers/date_helper.dart <==
import 'package:intl/intl.dart';

class DateHelper {
  static const List<String> _monthNames = [
    "January",
    "February",
    "March",
    "April",
    "May",
    "June",
    "July",
    "August",
    "September",
    "October",
    "November",
    "December"
  ];

  static const days = [
    'Monday',
    'Tuesday',
    'Wednesday',
    'Thursday',
    'Friday',
    'Saturday',
    'Sunday',
  ];

  static const List<String> _shortMonthNames = [
    'Jan',
    'Feb',
    'Mar',
    'Apr',
    'May',
    'Jun',
    'Jul',
    'Aug',
    'Sep',
    'Oct',
    'Nov',
    'Dec'
  ];

  static String convertNumberToTwo(int number) {
    if (number < 10) {
      return "0$number";
    }
    return "$number";
  }

  static String getMonth(int month) {
    return _monthNames[(month % 13) - 1];
  }

  static String getShortMonth(int month) {
    return _shortMonthNames[(month % 13) - 1];
  }

  static String getDateString(DateTime time) {
    Duration diff = DateTime.now().difference(time);
    if (diff.inHours < 24 && time.day == DateTime.now().day) {
      return "Today";
    } else if (diff.inDays == 1) {
      return "Yesterday";
    }
    return DateFormat.yMMMMd('en_US').format(time);
  }

  static DateTime getDate(DateTime time) {
    return DateTime(time.year, time.month, time.day);
  }

  static String getTimeString(DateTime time) {
    int hour = time.hour;
    if (hour != 12) {
      hour = hour % 12;
    }
    return "${hour == 0 ? "12" : "$hour"}:${convertNumberToTwo(time.minute)} ${time.hour < 12 ? "am" : "pm"}";
  }

  static String beautifyDate(DateTime time, {bool relative = true}) {
    if (time == null) {
      return null;
    }
    if (relative) {
      if (DateTime.now().day == time.day) {
        return getTimeString(time);
      }
      if (DateTime.now().day - time.day == 1) {
        return "Yesterday";
      }
      if (DateTime.now().day - time.day < 7) {
        return "${days[(time.weekday) % 7]}";
      }
    }
    return getMonthTimeString(time);
  }

  static String getLongMonthTimeString(DateTime time) {
    if (time == null) {
      return "";
    }
    return "${getMonth(time.month)} ${time.day}, ${time.year}";
  }

  static String getMonthTimeString(DateTime time) {
    if (time == null) {
      return "";
    }
    return "${getShortMonth(time.month)} ${time.day}, ${time.year}";
  }

  static bool isTimeZoneSame(Duration otherZoneOffset) {
    return DateTime.now().timeZoneOffset == otherZoneOffset;
  }

  static DateTime convertToLocal(DateTime time) {
    return time.add(DateTime.now().timeZoneOffset);
    // return time;
  }

  static DateTime convertToGlobal(DateTime time) {
    return time.subtract(DateTime.now().timeZoneOffset);
    // return time;
  }

  static bool compareYearDates(DateTime d1, DateTime d2) {
    if (d1.year == d2.year && d1.month == d2.month && d1.day == d2.day) {
      return true;
    }
    return false;
  }

  static String getAudioDuration(Duration duration) {
    String result = "";
    int seconds = duration.inSeconds;
    while (seconds != 0) {
      result =
          ":${convertNumberToTwo((seconds % 60) == 0 ? 0 : seconds % 60)}" +
              result;
      seconds = seconds ~/ 60;
    }
    if (duration.inSeconds < 60) {
      return "00$result";
    }
    result = result.substring(1);

    return result;
  }

  ///
  /// Json Methods
  ///

  // Will return local dates
  // Will return local dates
  static DateTime convertFromString(val) {
    if (val == null) {
      return null;
    }

    // DateTime time = DateTime.parse(val);
    // DateTime nowtime = DateTime.now();
    // time = time.add(nowtime.timeZoneOffset);
    return DateTime.parse(val).toLocal();
  }

  static String convertToString(DateTime time) {
    // time = time.subtract(time.timeZoneOffset);
    return time?.toUtc()?.toIso8601String();
  }
}

==> ocg_app-0.0.25.tar.gz: lib/src/helpers/date_helper.dart <==
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';

class DateHelper {
  static const List<String> _monthNames = [
    "January",
    "February",
    "March",
    "April",
    "May",
    "June",
    "July",
    "August",
    "September",
    "October",
    "November",
    "December"
  ];

  static const days = [
    'Monday',
    'Tuesday',
    'Wednesday',
    'Thursday',
    'Friday',
    'Saturday',
    'Sunday',
  ];

  static const List<String> _shortMonthNames = [
    'Jan',
    'Feb',
    'Mar',
    'Apr',
    'May',
    'Jun',
    'Jul',
    'Aug',
    'Sep',
    'Oct',
    'Nov',
    'Dec'
  ];

  static String convertNumberToTwo(int number) {
    if (number < 10) {
      return "0$number";
    }
    return "$number";
  }

  static String getMonth(int month) {
    return _monthNames[(month % 13) - 1];
  }

  static String getShortMonth(int month) {
    return _shortMonthNames[(month % 13) - 1];
  }

  static String getDateString(DateTime time) {
    Duration diff = DateTime.now().difference(time);
    if (diff.inHours < 24 && time.day == DateTime.now().day) {
      return "Today";
    } else if (diff.inDays == 1) {
      return "Yesterday";
    }
    return DateFormat.yMMMMd('en_US').format(time);
  }

  static DateTime getDate(DateTime time) {
    return DateTime(time.year, time.month, time.day);
  }

  static String getTimeString(DateTime time) {
    int hour = time.hour;
    if (hour != 12) {
      hour = hour % 12;
    }
    return "${hour == 0 ? "12" : "$hour"}:${convertNumberToTwo(time.minute)} ${time.hour < 12 ? "am" : "pm"}";
  }

  static String beautifyDate(DateTime time, {bool relative = true}) {
    if (time == null) {
      return null;
    }
    if (relative) {
      if (DateTime.now().day == time.day) {
        return getTimeString(time);
      }
      if (DateTime.now().day - time.day == 1) {
        return "Yesterday";
      }
      if (DateTime.now().day - time.day < 7) {
        return "${days[(time.weekday) % 7]}";
      }
    }
    return getMonthTimeString(time);
  }

  static String getLongMonthTimeString(DateTime time) {
    if (time == null) {
      return "";
    }
    return "${getMonth(time.month)} ${time.day}, ${time.year}";
  }

  static String getMonthTimeString(DateTime time) {
    if (time == null) {
      return "";
    }
    return "${getShortMonth(time.month)} ${time.day}, ${time.year}";
  }

  static bool isTimeZoneSame(Duration otherZoneOffset) {
    return DateTime.now().timeZoneOffset == otherZoneOffset;
  }

  static DateTime convertToLocal(DateTime time) {
    return time.add(DateTime.now().timeZoneOffset);
    // return time;
  }

  static DateTime convertToGlobal(DateTime time) {
    return time.subtract(DateTime.now().timeZoneOffset);
    // return time;
  }

  static bool compareYearDates(DateTime d1, DateTime d2) {
    if (d1.year == d2.year && d1.month == d2.month && d1.day == d2.day) {
      return true;
    }
    return false;
  }

  static String getAudioDuration(Duration duration) {
    String result = "";
    int seconds = duration.inSeconds;
    while (seconds != 0) {
      result =
          ":${convertNumberToTwo((seconds % 60) == 0 ? 0 : seconds % 60)}" +
              result;
      seconds = seconds ~/ 60;
    }
    if (duration.inSeconds < 60) {
      return "00$result";
    }
    result = result.substring(1);

    return result;
  }

  ///
  /// Json Methods
  ///

  // Will return local dates
  // Will return local dates
  static DateTime convertFromString(val) {
    if (val == null) {
      return null;
    }

    // DateTime time = DateTime.parse(val);
    // DateTime nowtime = DateTime.now();
    // time = time.add(nowtime.timeZoneOffset);
    return DateTime.parse(val).toLocal();
  }

  static String convertToString(DateTime time) {
    return time.toIso8601String();
  }

  static int convertToMilliseconds(DateTime time) {
    return time.millisecondsSinceEpoch;
  }

  static DateTime convertFromMilliseconds(int time) {
    return DateTime.fromMillisecondsSinceEpoch(time);
  }
}
